==> jc-1.4.0.tar.gz: java/security/spec/RSAOtherPrimeInfo.h <==
// public class java.security.spec.RSAOtherPrimeInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9cdbc894ade016a9 java_security_spec_RSAOtherPrimeInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_RSAOtherPrimeInfo_H_
#define _JC_java_security_spec_RSAOtherPrimeInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$sub_refs	_jc_java_security_spec_RSAOtherPrimeInfo$sub_refs;
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$sub_nonrefs	_jc_java_security_spec_RSAOtherPrimeInfo$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$refs	_jc_java_security_spec_RSAOtherPrimeInfo$refs;
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$nonrefs	_jc_java_security_spec_RSAOtherPrimeInfo$nonrefs;
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$object	_jc_java_security_spec_RSAOtherPrimeInfo$object;

typedef const struct _jc_java_security_spec_RSAOtherPrimeInfo$vmethods	_jc_java_security_spec_RSAOtherPrimeInfo$vmethods;
typedef const struct _jc_java_security_spec_RSAOtherPrimeInfo$vtable	_jc_java_security_spec_RSAOtherPrimeInfo$vtable;
typedef const struct _jc_java_security_spec_RSAOtherPrimeInfo$vtype	_jc_java_security_spec_RSAOtherPrimeInfo$vtype;

// Constructors
extern void _jc_java_security_spec_RSAOtherPrimeInfo$method$_init$6cf26681d886fcf0(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAOtherPrimeInfo$method$getCrtCoefficient$3b26e563f0a78fa8(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAOtherPrimeInfo$method$getExponent$1a8b6b4f0e9880b9(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAOtherPrimeInfo$method$getPrime$55fcad22219b813a(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAOtherPrimeInfo$method_info$getCrtCoefficient$3b26e563f0a78fa8;
extern _jc_method _jc_java_security_spec_RSAOtherPrimeInfo$method_info$getExponent$1a8b6b4f0e9880b9;
extern _jc_method _jc_java_security_spec_RSAOtherPrimeInfo$method_info$getPrime$55fcad22219b813a;

// Virtual methods structure
struct _jc_java_security_spec_RSAOtherPrimeInfo$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getCrtCoefficient$3b26e563f0a78fa8)(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *);
	struct _jc_java_math_BigInteger$object	*(*getExponent$1a8b6b4f0e9880b9)(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrime$55fcad22219b813a)(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *);
};

// Vtable
struct _jc_java_security_spec_RSAOtherPrimeInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAOtherPrimeInfo$vmethods	java_security_spec_RSAOtherPrimeInfo;
};

// Vtype
struct _jc_java_security_spec_RSAOtherPrimeInfo$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAOtherPrimeInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAOtherPrimeInfo$sub_refs {
	struct _jc_java_math_BigInteger$object	*prime;
	struct _jc_java_math_BigInteger$object	*primeExponent;
	struct _jc_java_math_BigInteger$object	*crtCoefficient;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAOtherPrimeInfo$refs {
    _jc_java_security_spec_RSAOtherPrimeInfo$sub_refs	java_security_spec_RSAOtherPrimeInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAOtherPrimeInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAOtherPrimeInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAOtherPrimeInfo$sub_nonrefs	java_security_spec_RSAOtherPrimeInfo;
};

// Object instance structure
struct _jc_java_security_spec_RSAOtherPrimeInfo$object {
	_jc_java_security_spec_RSAOtherPrimeInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAOtherPrimeInfo$vtype	*vtype;
	_jc_java_security_spec_RSAOtherPrimeInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAOtherPrimeInfo$vtype _jc_java_security_spec_RSAOtherPrimeInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAOtherPrimeInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAOtherPrimeInfo$class_object;

#endif	/* _JC_java_security_spec_RSAOtherPrimeInfo_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/RSAOtherPrimeInfo.h <==
// public class java.security.spec.RSAOtherPrimeInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9cdbc894ade016a9 java_security_spec_RSAOtherPrimeInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_RSAOtherPrimeInfo_H_
#define _JC_java_security_spec_RSAOtherPrimeInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$sub_refs	_jc_java_security_spec_RSAOtherPrimeInfo$sub_refs;
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$sub_nonrefs	_jc_java_security_spec_RSAOtherPrimeInfo$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$refs	_jc_java_security_spec_RSAOtherPrimeInfo$refs;
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$nonrefs	_jc_java_security_spec_RSAOtherPrimeInfo$nonrefs;
typedef struct _jc_java_security_spec_RSAOtherPrimeInfo$object	_jc_java_security_spec_RSAOtherPrimeInfo$object;

typedef const struct _jc_java_security_spec_RSAOtherPrimeInfo$vmethods	_jc_java_security_spec_RSAOtherPrimeInfo$vmethods;
typedef const struct _jc_java_security_spec_RSAOtherPrimeInfo$vtable	_jc_java_security_spec_RSAOtherPrimeInfo$vtable;
typedef const struct _jc_java_security_spec_RSAOtherPrimeInfo$vtype	_jc_java_security_spec_RSAOtherPrimeInfo$vtype;

// Constructors
extern void _jc_java_security_spec_RSAOtherPrimeInfo$method$_init$6cf26681d886fcf0(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAOtherPrimeInfo$method$getCrtCoefficient$3b26e563f0a78fa8(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAOtherPrimeInfo$method$getExponent$1a8b6b4f0e9880b9(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAOtherPrimeInfo$method$getPrime$55fcad22219b813a(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAOtherPrimeInfo$method_info$getCrtCoefficient$3b26e563f0a78fa8;
extern _jc_method _jc_java_security_spec_RSAOtherPrimeInfo$method_info$getExponent$1a8b6b4f0e9880b9;
extern _jc_method _jc_java_security_spec_RSAOtherPrimeInfo$method_info$getPrime$55fcad22219b813a;

// Virtual methods structure
struct _jc_java_security_spec_RSAOtherPrimeInfo$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getCrtCoefficient$3b26e563f0a78fa8)(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getExponent$1a8b6b4f0e9880b9)(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrime$55fcad22219b813a)(_jc_env *, struct _jc_java_security_spec_RSAOtherPrimeInfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_RSAOtherPrimeInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAOtherPrimeInfo$vmethods	java_security_spec_RSAOtherPrimeInfo;
};

// Vtype
struct _jc_java_security_spec_RSAOtherPrimeInfo$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAOtherPrimeInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAOtherPrimeInfo$sub_refs {
	struct _jc_java_math_BigInteger$object	*prime;
	struct _jc_java_math_BigInteger$object	*primeExponent;
	struct _jc_java_math_BigInteger$object	*crtCoefficient;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAOtherPrimeInfo$refs {
    _jc_java_security_spec_RSAOtherPrimeInfo$sub_refs	java_security_spec_RSAOtherPrimeInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAOtherPrimeInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAOtherPrimeInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAOtherPrimeInfo$sub_nonrefs	java_security_spec_RSAOtherPrimeInfo;
};

// Object instance structure
struct _jc_java_security_spec_RSAOtherPrimeInfo$object {
	_jc_java_security_spec_RSAOtherPrimeInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAOtherPrimeInfo$vtype	*vtype;
	_jc_java_security_spec_RSAOtherPrimeInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAOtherPrimeInfo$vtype _jc_java_security_spec_RSAOtherPrimeInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAOtherPrimeInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAOtherPrimeInfo$class_object;

#endif	/* _JC_java_security_spec_RSAOtherPrimeInfo_H_ */
